@@ -90,7 +90,13 @@ def write_ssl_resp_yes(context: Context):
 def read_startup_message(context: Context, inner_buff: Optional[ReadingIO] = None):
     try:
 
-        startup_front = StartupMessage.read(context.input if inner_buff is None else inner_buff)
+        if inner_buff is None:
+            io = context.input
+        else:
+            logging.error("Using inner buffer to read the startup message")
+            io = inner_buff
+
+        startup_front = StartupMessage.read(io)
 
         logging.error(f"Got startup message: {startup_front}")
 
