@@ -68,25 +68,16 @@ class ReadingIO:
         then a bytes message of message_len = len - 4
         :return: a ReadingIO object or None
         """
-        try:
-            l = self.read_int32()
-            msg_len = l - 4
+        l = self.read_int32()
+        msg_len = l - 4
 
-            if msg_len <= 0:
-                return None, 0
+        if msg_len <= 0:
+            return None, 0
 
-            check_max_size(msg_len)
+        check_max_size(msg_len)
 
-            msg = self.read_bytes(msg_len)
-            return ReadingIO(io.BytesIO(msg)), msg_len
-        except NoData as e:
-            if timeout < 1:
-                raise e
-
-            if e.got_bytes == 0:
-                # idle till timeout on the connection
-                time.sleep(1)
-                return self.read_int32_delim_message(self, timeout=timeout - 1)
+        msg = self.read_bytes(msg_len)
+        return ReadingIO(io.BytesIO(msg)), msg_len
 
 
 class WritingIO:
